@@ -40,7 +40,7 @@ use JSON qw();
 use URI::Encode qw(uri_encode);
 use POSIX qw(strftime);
 
-our $VERSION=1.16;
+our $VERSION=1.17;
 
 use base qw(Net::SolarWinds::ConstructorHash Net::SolarWinds::LogMethods Net::SolarWinds::Helper);
 use constant RESULT_CLASS=>'Net::SolarWinds::Result';
@@ -641,11 +641,84 @@ sub getNodesByID {
   $self->log_info("stopping");
   return $result;
 }
+
 =item * my $result=$self->createNode(key=>value);
 
 Creates a node.
 Returns a Carter::Result Object: Retuns a data structure on sucess returns why it faield on false.
 
+Note, there are no presets when using this method!
+
+=cut
+
+sub nopresetsCreateNode {
+  my ($self,%args)=@_;
+
+  $self->log_info("starting");
+  # Caption 
+
+  my $path='Create/Orion.Nodes';
+  my $request=$self->build_request('POST',$path,{%args});
+  my $result=$self->run_request($request);
+
+  unless($result) {
+    $self->log_error("Failed to create node error was: $result");
+    $self->log_info("stopping");
+    return $result;
+  }
+  my $swis=$result->get_data;
+  $swis=~ s/(?:^"|"$)//sg;
+  my ($node_id)=$swis=~ /(\d+)$/s;
+
+  $self->log_info("stopping");
+  return $self->RESULT_CLASS->new_true({Uri=>$swis,NodeID=>$node_id});
+}
+
+
+=item * my $result=$self->createNode(key=>value);
+
+Creates a node.
+Returns a Carter::Result Object: Retuns a data structure on sucess returns why it faield on false.
+
+  # the defautl key/value list is
+    qw(
+      ObjectSubType      SNMP
+      EntityType         Orion.Nodes
+      DynamicIP          false
+      EngineID           1
+      Status             1
+      UnManaged          false
+      Allow64BitCounters true
+      ObjectSubType      SNMP
+      SNMPVersion        2
+      Community          public
+      VendorIcon         8072.gif
+      NodeDescription    Hardware
+
+    ),
+      IOSImage=>"",
+      IOSVersion=>"",
+      Pollinterval=>60,
+      SysObjectID=>"1.3.6.1.4.1.8072.3.2.10",
+      MachineType=>"net-snmp - Linux",
+      StatCollection=>10,
+      CPULoad=>"-2",
+      MemoryUsed=>"-2",
+      PercentMemoryUsed=>"-2",
+      BufferNoMemThisHour=>"0",
+      BufferNoMemToday=>"0",
+      BufferSmMissThisHour=>"0",
+      BufferSmMissToday=>"0",
+      BufferMdMissThisHour=>"0",
+      BufferMdMissToday=>"0",
+      BufferBgMissThisHour=>"0",
+      BufferBgMissToday=>"0",
+      BufferLgMissThisHour=>"0",
+      BufferLgMissToday=>"0",
+      BufferHgMissThisHour=>"0",
+      BufferHgMissToday=>"0",
+  
+
 =cut
 
 sub createNode {
@@ -692,6 +765,7 @@ sub createNode {
       BufferHgMissToday=>"0",
       %args
   );
+
   unless(exists $args{IPAddress}) {
     $self->log_error("IPAddress must be set");
     $self->log_info("stopping");
@@ -701,25 +775,11 @@ sub createNode {
   # start building our required but often times missing key value pairs
   $args{IPAddressGUID}=$self->ip_to_gui($args{IPAddress}) unless exists $args{IPAddressGUID};
   $args{Caption}=$self->ip_to_reverse_hex($args{IPAddress}) unless exists $args{Caption};
+  
+  $self->log_info('stopping');
 
-
-  my $path='Create/Orion.Nodes';
-  my $request=$self->build_request('POST',$path,{%args});
-  my $result=$self->run_request($request);
-
-  unless($result) {
-    $self->log_error("Failed to create node error was: $result");
-    $self->log_info("stopping");
-    return $result;
-  }
-  my $swis=$result->get_data;
-  $swis=~ s/(?:^"|"$)//sg;
-  my ($node_id)=$swis=~ /(\d+)$/s;
-
-  $self->log_info("stopping");
-  return $self->RESULT_CLASS->new_true({Uri=>$swis,NodeID=>$node_id});
+  return $self->nopresetsCreateNode(%args);
 }
-
 =item * my $result=$self->getNodeUri($node_id);
 
 When true the Net::SolarWinds::Result object contains the node uri.
